# Artificial Intelligence
[![Build status](https://github.com/jakkes/AI_Projects/actions/workflows/python-app.yml/badge.svg?branch=master)](https://github.com/jakkes/AI_Projects/actions/workflows/python-app.yml)

A collection of AI algorithms, RL agents, and more.


## Documentation
https://jakkes.github.io/AI_Projects/ai



## Installing
```
pip install ai-projects
```
